@@ -7,7 +7,6 @@ import zipfile
 from pathlib import Path
 
 import pytest
-from pdm.models.pip_shims import global_tempdir_manager
 from pdm.utils import cd, is_editable
 
 from pdm_packer.env import PackEnvironment
@@ -23,27 +22,31 @@ def example_project(invoke, main):
         "import requests\ndef main():\n    print(requests.__version__)\n"
     )
     project = main.create_project(tmp_path)
-    project.pyproject = {
-        "project": {
-            "name": "test_app",
-            "version": "0.1.0",
-            "requires-python": ">=3.7",
-            "dependencies": ["requests==2.24.0"],
-        },
-        "build-system": {"requires": ["pdm-pep517"], "build-backend": "pdm.pep517.api"},
-    }
-    project.write_pyproject()
+    project.pyproject.set_data(
+        {
+            "project": {
+                "name": "test_app",
+                "version": "0.1.0",
+                "requires-python": ">=3.7",
+                "dependencies": ["requests==2.24.0"],
+            },
+            "build-system": {
+                "requires": ["pdm-pep517"],
+                "build-backend": "pdm.pep517.api",
+            },
+        }
+    )
+    project.pyproject.write()
     invoke(["install"], obj=project)
 
     return project
 
 
 def test_pack_env_all_non_editable(example_project):
-    with global_tempdir_manager():
-        with PackEnvironment(example_project) as env:
-            env.prepare_lib_for_pack()
-            for _, v in env.get_working_set().items():
-                assert not is_editable(v)
+    with PackEnvironment(example_project) as env:
+        env.prepare_lib_for_pack()
+        for _, v in env.get_working_set().items():
+            assert not is_editable(v)
 
 
 def test_create_without_main_error(example_project, invoke):
@@ -113,8 +116,8 @@ def test_create_pyz_without_py(example_project, invoke, tmp_path):
 
 
 def test_pack_respect_console_script(example_project, invoke, tmp_path):
-    example_project.meta["scripts"] = {"app": "app:main"}
-    example_project.write_pyproject()
+    example_project.pyproject.metadata["scripts"] = {"app": "app:main"}
+    example_project.pyproject.write()
     with cd(tmp_path):
         invoke(["pack"], obj=example_project)
     output = tmp_path / "test_app.pyz"
